import * as AWS from 'aws-sdk';
import { ILogger } from 'typescript-ilogger';
import { BaseClass } from 'typescript-helper-functions';
import { IAPIGatewayHelper } from './interface';
/**
 * APIGateway Helper
 */
export declare class APIGatewayHelper extends BaseClass implements IAPIGatewayHelper {
    /**
     * AWS Repository for APIGateway
     */
    Repository: AWS.APIGateway;
    /**
     * Initializes new instance of APIGatewayHelper
     * @param logger {ILogger} Injected logger
     * @param repository {AWS.APIGateway} Injected Repository. A new repository will be created if not supplied
     * @param options {AWS.APIGateway.ClientConfiguration} Injected configuration if a Repository is supplied
     */
    constructor(logger: ILogger, repository?: AWS.APIGateway, options?: AWS.APIGateway.ClientConfiguration);
    /**
     * Create an API key
     * @param name {string} Name of new API key
     * @param description {string} Description of new API key
     * @param value {string} Value to give new API key. If not provided, will be auto generated
     */
    CreateApiKeyAsync(name: string, description: string, value?: string): Promise<AWS.APIGateway.ApiKey>;
    /**
     * Create an usage plan
     * @param name {string} Usage plan name
     * @param description {string} Usage plan description
     * @param apiStages {AWS.APIGateway.ApiStage[]} API stages to attach this usage plan to
     * @param quota {AWS.APIGateway.QuotaSettings} Quota settings
     * @param throttle {AWS.APIGateway.ThrottleSettings} Throttle settings
     */
    CreateUsagePlanAsync(name: string, description: string, apiStages: AWS.APIGateway.ApiStage[], quota?: AWS.APIGateway.QuotaSettings, throttle?: AWS.APIGateway.ThrottleSettings): Promise<AWS.APIGateway.UsagePlan>;
    /**
     * Create an usage plan key
     * @param keyId {string} ID of usage plan key
     * @param keyType {string} Type of key to create
     * @param usagePlanId {string} Usage plan id to associate with
     */
    CreateUsagePlanKeyAsync(keyId: string, keyType: string, usagePlanId: string): Promise<AWS.APIGateway.UsagePlanKey>;
    /**
     * Delete an API key
     * @param apiKey {string} API key to delete
     */
    DeleteApiKeyAsync(apiKey: string): Promise<object>;
    /**
     * Delete an usage plan
     * @param usagePlanId {string} Usage plan to delete
     */
    DeleteUsagePlanAsync(usagePlanId: string): Promise<object>;
    /**
     * Delete an usage plan key
     * @param keyId {string} Key to delete
     * @param usagePlanId {string} Usage plan that is associated with this key
     */
    DeleteUsagePlanKeyAsync(keyId: string, usagePlanId: string): Promise<object>;
    /**
     * Get an API key
     * @param apiKey {string} API Key
     */
    GetApiKeyAsync(apiKey: string): Promise<AWS.APIGateway.ApiKey>;
}
