"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.APIGatewayMock = void 0;
const typescript_helper_functions_1 = require("typescript-helper-functions");
// tslint:disable-next-line: no-var-requires
const AWS = require('aws-sdk');
/**
 * APIGateway Mock class
 */
class APIGatewayMock extends typescript_helper_functions_1.BaseMock {
    constructor() {
        super(...arguments);
        /**
         * Mocks an AWS.APIGateway.ApiKey response
         */
        this.ApiKey = {};
        /**
         * Mocks an AWS.APIGateway.DeleteApiKey response
         * Technically does not exist
         */
        this.DeleteApiKey = {};
        /**
         * Mocks an AWS.APIGateway.DeleteUsagePlan response
         * Technically does not exist
         */
        this.DeleteUsagePlan = {};
        /**
         * Mocks an AWS.APIGateway.DeleteUsagePlanKey response
         * Technically does not exist
         */
        this.DeleteUsagePlanKey = {};
        /**
         * Mocks an AWS.APIGateway.UsagePlan response
         */
        this.UsagePlan = {};
        /**
         * Mocks an AWS.APIGateway.UsagePlanKey response
         */
        this.UsagePlanKey = {};
    }
    /**
     * Create the APIGateway mock
     */
    CreateMock(returnError) {
        const rejectResponse = new Error(`AWS Error`);
        // implement the AWS responses
        const awsResponses = {
            // create api key response
            createApiKey: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.ApiKey);
                }),
            },
            // create usage plan response
            createUsagePlan: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.UsagePlan);
                }),
            },
            // create usage plan key response
            createUsagePlanKey: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.UsagePlanKey);
                }),
            },
            // delete api key response
            deleteApiKey: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.DeleteApiKey);
                }),
            },
            // delete usage plan response
            deleteUsagePlan: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.DeleteUsagePlan);
                }),
            },
            // delete usage plan key response
            deleteUsagePlanKey: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.DeleteUsagePlanKey);
                }),
            },
            // get api key response
            getApiKey: {
                promise: jest.fn().mockImplementation(() => {
                    return returnError ?
                        Promise.reject(rejectResponse) :
                        Promise.resolve(this.ApiKey);
                }),
            },
        };
        // create the functions
        let functions = new AWS.APIGateway();
        functions = {
            createApiKey: () => awsResponses.createApiKey,
            createUsagePlan: () => awsResponses.createUsagePlan,
            createUsagePlanKey: () => awsResponses.createUsagePlanKey,
            deleteApiKey: () => awsResponses.deleteApiKey,
            deleteUsagePlan: () => awsResponses.deleteUsagePlan,
            deleteUsagePlanKey: () => awsResponses.deleteUsagePlanKey,
            getApiKey: () => awsResponses.getApiKey,
        };
        return functions;
    }
}
exports.APIGatewayMock = APIGatewayMock;
//# sourceMappingURL=mock.js.map